@@ -27,6 +27,7 @@ using System.Reflection;
 using gbrainy.Core.Main;
 using gbrainy.Core.Platform;
 using gbrainy.Core.Services;
+using gbrainy.Core.Libraries;
 using gbrainy.Clients.Classical.Dialogs;
 using gbrainy.Clients.Classical.Widgets;
 
@@ -35,16 +36,9 @@ using Mono.Addins;
 using Mono.Addins.Setup;
 #endif
 
-#if GNOME
-using Gnome;
-#endif
-
 namespace gbrainy.Clients.Classical
 {
 	public class GtkClient
-#if GNOME
-		: Program
-#endif
 	{
 		[GtkBeans.Builder.Object("gbrainy")] Gtk.Window app_window;
 		[GtkBeans.Builder.Object] Gtk.CheckMenuItem showtoolbar_menuitem;
@@ -78,17 +72,16 @@ namespace gbrainy.Clients.Classical
 		bool low_res;
 		bool full_screen;
 		GameSession.Types initial_session;
+		static bool pluggins_loaded;
 
 		public readonly int MIN_TRANSLATION = 80;
 
-		public GtkClient ()
-#if GNOME
-		: base ("gbrainy", Defines.VERSION, Modules.UI, new string [0])
-#endif
+		public GtkClient (ITranslations translations)
 		{
+			Translations = translations;
 			if (Preferences.Get <bool> (Preferences.EnglishKey) == false)
 			{
-				Catalog.Init ("gbrainy", Defines.GNOME_LOCALE_DIR);
+				translations.Init ("gbrainy", Defines.GNOME_LOCALE_DIR);
 			}
 
 			Unix.FixLocaleInfo ();
@@ -103,13 +96,16 @@ namespace gbrainy.Clients.Classical
 			set { initial_session = value; }
 		}
 
+		ITranslations Translations {get; set;}
+
 		public void Initialize ()
 		{
-			session = new GameSession ();
+			session = new GameSession (Translations);
+			
 			GameManagerPreload (session.GameManager);
-			Console.WriteLine (session.GameManager.GetGamesSummary ());
+			Console.WriteLine (session.GameManager.GetGamesSummary (Translations));
 
-			session.GameManager.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
+			session.PlayList.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
 			session.DrawRequest += SessionDrawRequest;
 			session.UpdateUIElement += SessionUpdateUIElement;
 			session.SynchronizingObject = new GtkSynchronize ();
@@ -123,7 +119,12 @@ namespace gbrainy.Clients.Classical
 			gm.LoadAssemblyGames (Defines.GAME_ASSEMBLY);
 			gm.LoadVerbalAnalogies (System.IO.Path.Combine (Defines.DATA_DIR, Defines.VERBAL_ANALOGIES));
 			gm.LoadGamesFromXml (System.IO.Path.Combine (Defines.DATA_DIR, Defines.GAMES_FILE));
-			gm.LoadPlugins ();
+
+			if (Preferences.Get <bool> (Preferences.LoadPlugginsKey))
+			{			
+				gm.LoadPlugins ();
+				pluggins_loaded = true;
+			}
 		}
 
 		void BuildUI ()
@@ -199,7 +200,16 @@ namespace gbrainy.Clients.Classical
 				showtoolbar_menuitem.Active = false;
 
 		#if MONO_ADDINS
-			extensions_menuitem.Activated += delegate (object sender, EventArgs ar) { Mono.Addins.Gui.AddinManagerWindow.Run (app_window);};
+			extensions_menuitem.Activated += delegate (object sender, EventArgs ar) 
+			{
+				if (pluggins_loaded == false)
+				{			
+					session.GameManager.LoadPlugins ();
+				}
+				Mono.Addins.Gui.AddinManagerWindow.Run (app_window);
+				GameManagerPreload (session.GameManager);
+				CustomGameDialog.Clear ();
+			};
 		#else
 			extensions_menuitem.Visible = false;
 		#endif
@@ -424,9 +434,9 @@ namespace gbrainy.Clients.Classical
 
 			correct = session.ScoreGame (answer_entry.Text);
 			if (correct)
-				answer = Catalog.GetString ("Congratulations.");
+				answer = Translations.GetString ("Congratulations.");
 			else
-				answer = Catalog.GetString ("Incorrect answer.");
+				answer = Translations.GetString ("Incorrect answer.");
 
 			session.EnableTimer = false;
 			answer_entry.Text = String.Empty;
@@ -443,21 +453,12 @@ namespace gbrainy.Clients.Classical
 
 		void OnQuit (object sender, EventArgs args)
 		{
-#if GNOME
-			Quit ();
-#else
 			Gtk.Application.Quit ();
-#endif
-
 		}
 
 		void OnDeleteWindow (object sender, DeleteEventArgs args)
 		{
-#if GNOME
-			Quit ();
-#else
 			Gtk.Application.Quit ();
-#endif
 		}
 
 		void OnNextButtonClicked (object sender, EventArgs args)
@@ -483,25 +484,25 @@ namespace gbrainy.Clients.Classical
 		void OnNewGame (GameSession.Types type)
 		{
 			// If the translation is lower than MIN_TRANSLATION explain that running the English version is an option
-			if (ShowTranslationWarning ())
-				Translations ();
+			if (ShouldShowTranslationWarning ())
+				ShowTranslationWarning ();
 
 			session.Type = type;
 			session.New ();
 			GetNextGame ();
 			GameSensitiveUI ();
-			UpdateSolution (Catalog.GetString ("Once you have an answer type it in the \"Answer:\" entry box and press the \"OK\" button."),
+			UpdateSolution (Translations.GetString ("Once you have an answer type it in the \"Answer:\" entry box and press the \"OK\" button."),
 				GameDrawingArea.SolutionType.Tip);
 			UpdateStatusBar ();
 		}
 
-		public bool ShowTranslationWarning ()
+		public bool ShouldShowTranslationWarning ()
 		{
 			// Notify the user once per version only
 			if (String.Compare (Preferences.Get <string> (Preferences.EnglishVersionKey), Defines.VERSION, 0) == 0)
 				return false;
 
-			int percentage = ServiceLocator.Instance.GetService <ITranslations> ().TranslationPercentage;
+			int percentage = Translations.TranslationPercentage;
 			if (percentage > 0 && percentage < MIN_TRANSLATION)
 			{
 				Preferences.Set <string> (Preferences.EnglishVersionKey, Defines.VERSION);
@@ -512,7 +513,7 @@ namespace gbrainy.Clients.Classical
 			return false;
 		}
 
-		void Translations ()
+		void ShowTranslationWarning ()
 		{		
 			HigMessageDialog dlg;
 	
@@ -520,8 +521,8 @@ namespace gbrainy.Clients.Classical
 				Gtk.DialogFlags.DestroyWithParent,
 				Gtk.MessageType.Warning,
 				Gtk.ButtonsType.Ok,
-				Catalog.GetString ("The level of translation of gbrainy for your language is low."),
-				Catalog.GetString ("You may be exposed to partially translated games making it more difficult to play. If you prefer to play in English, there is an option for doing so in gbrainy's Preferences."));
+				Translations.GetString ("The level of translation of gbrainy for your language is low."),
+				Translations.GetString ("You may be exposed to partially translated games making it more difficult to play. If you prefer to play in English, there is an option for doing so in gbrainy's Preferences."));
 		
 			try {
 	 			dlg.Run ();
@@ -549,7 +550,7 @@ namespace gbrainy.Clients.Classical
 		{
 			PdfExportDialog pdf;
 
-			pdf = new PdfExportDialog ();
+			pdf = new PdfExportDialog (session.GameManager, Translations);
 			pdf.Run ();
 			pdf.Destroy ();
 		}
@@ -558,10 +559,10 @@ namespace gbrainy.Clients.Classical
 		{
 			PreferencesDialog dialog;
 
-			dialog = new PreferencesDialog (session.PlayerHistory);
+			dialog = new PreferencesDialog (Translations, session.PlayerHistory);
 			if ((Gtk.ResponseType) dialog.Run () == ResponseType.Ok) {
 				session.Difficulty = (GameDifficulty) Preferences.Get <int> (Preferences.DifficultyKey);
-				session.GameManager.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
+				session.PlayList.ColorBlind = Preferences.Get <bool> (Preferences.ColorBlindKey);
 
 				if (dialog.NewThemeSet == true)
 					drawing_area.ReloadBackground ();
@@ -573,7 +574,7 @@ namespace gbrainy.Clients.Classical
 		{
 			CustomGameDialog dialog;
 
-			dialog = new CustomGameDialog (session.GameManager);
+			dialog = new CustomGameDialog (Translations, session);
 			dialog.Run ();
 			dialog.Destroy ();
 
@@ -617,12 +618,12 @@ namespace gbrainy.Clients.Classical
 			if (pause) {
 				drawing_area.Paused = false;
 				toolbar.PauseButton.StockId = "pause";
-				toolbar.PauseButton.Label = Catalog.GetString ("Pause");
+				toolbar.PauseButton.Label = Translations.GetString ("Pause");
 				ActiveInputControls (true);
 			} else {
 				drawing_area.Paused = true;
 				toolbar.PauseButton.StockId = "resume";
-				toolbar.PauseButton.Label = Catalog.GetString ("Resume");
+				toolbar.PauseButton.Label = Translations.GetString ("Resume");
 				ActiveInputControls (false);
 			}
 			UpdateStatusBar ();
@@ -699,7 +700,7 @@ namespace gbrainy.Clients.Classical
 		{
 			PlayerHistoryDialog dialog;
 
-			dialog = new PlayerHistoryDialog (session.PlayerHistory);
+			dialog = new PlayerHistoryDialog (Translations, session.PlayerHistory);
 			dialog.Run ();
 			dialog.Destroy ();
 		}
@@ -746,26 +747,26 @@ namespace gbrainy.Clients.Classical
 			}
 
 			DateTime start_time = DateTime.Now;
+			ITranslations translations = new TranslationsCatalog ();
 
 			InitCoreLibraries ();
 
-			GtkClient app = new GtkClient ();
+			GtkClient app = new GtkClient (translations);
 			CommandLine.Version ();
 
-			CommandLine line = new CommandLine (args);
+			CommandLine line = new CommandLine (translations, args);
 			line.Parse ();
 
 			if (line.Continue == false)
 				return;
-#if !GNOME
+
 			Gtk.Application.Init ();
-#endif
 
 			app.Initialize ();
 			// Set RandomOrder before setting the custom list then it has effect of custom games
-			app.Session.GameManager.RandomOrder = line.RandomOrder;
+			app.Session.PlayList.RandomOrder = line.RandomOrder;
 			if (line.PlayList.Length > 0) {
-				app.Session.GameManager.PlayList = line.PlayList;
+				app.Session.PlayList.PlayList = line.PlayList;
 				app.InitialSessionType = GameSession.Types.Custom;
 			}
 			app.ProcessDefaults ();
@@ -773,11 +774,7 @@ namespace gbrainy.Clients.Classical
 
 			TimeSpan span = DateTime.Now - start_time;
 			Console.WriteLine (Catalog.GetString ("Startup time {0}"), span);
-#if GNOME
-			app.Run ();
-#else
 			Gtk.Application.Run ();
-#endif
 		}
 	}
 }
