@@ -29,30 +29,56 @@ namespace gbrainy.Core.Main
 	{
 		static SVGImage image;
 
-		public CairoContextEx (IntPtr state, Gtk.Widget widget) : base (state, widget)
+		public CairoContextEx (IntPtr handle) : base (handle)
 		{
-			SetPangoNormalFontSize ();
+			CommonConstructor ();		
 		}
 
 		// Used by GeneratePDF
 		public CairoContextEx (Cairo.Surface s, string font, int dpis) : base (s, font, dpis)
 		{
+			CommonConstructor ();
+		}
+
+		void CommonConstructor ()
+		{
+			Theme theme;
+	
+			theme = ThemeManager.FromName (Preferences.Get <string> (Preferences.ThemeKey));
+			FontFace = theme.FontFace;
+
 			SetPangoNormalFontSize ();
 		}
+		
+		public static void ResetDrawBackgroundCache ()
+		{
+			if (image == null)
+				return;
+
+			image.Dispose ();
+			image = null;
+		}
 
 		virtual public void DrawBackground ()
 		{
 			try {
 				if (image == null)
-					image = new SVGImage (System.Reflection.Assembly.GetCallingAssembly (), "background.svg");
+				{
+					Theme theme;
+	
+					theme = ThemeManager.FromName (Preferences.Get <string> (Preferences.ThemeKey));
+					image = new SVGImage (System.IO.Path.Combine (Defines.DATA_DIR, theme.BackgroundImage));
+				}
 
 				Save ();
 				Rectangle (0, 0, 1, 1);
 				Scale (0.999 / image.Width, 0.999 / image.Height);
 				image.RenderToCairo (Handle);
 				Restore ();
-
-			} catch {
+			}
+			catch (Exception e)
+			{
+				Console.WriteLine ("CairoContextEx.DrawBackground {0}", e);
 			}
 		}
 
