@@ -19,8 +19,8 @@
 
 using System;
 using Cairo;
-using Mono.Unix;
 using System.Timers;
+using gbrainy.Core.Services;
 
 using gbrainy.Core.Views;
 
@@ -50,7 +50,7 @@ namespace gbrainy.Core.Main
 
 		public override string Question {
 			get {
-				return Catalog.GetString ("Memorize the objects below in the given time");
+				return Translations.GetString ("Memorize the objects below in the given time");
 			}
 		}
 
@@ -68,13 +68,13 @@ namespace gbrainy.Core.Main
 
 		protected override void Initialize ()
 		{
-			if (Preferences.GetBoolValue (Preferences.MemQuestionWarnKey) == false || 
+			if (Preferences.Get <bool> (Preferences.MemQuestionWarnKey) == false || 
 				IsPreviewMode == true) {
 				InitializeGame ();
 				return;
 			}
 
-			downview = new CountDownView (OnCountDownFinish);
+			downview = new CountDownView (Translations, OnCountDownFinish);
 			downview.SynchronizingObject = SynchronizingObject;
 			downview.DrawRequest += OnCountDownRedraw;
 			downview.Start ();
@@ -109,7 +109,7 @@ namespace gbrainy.Core.Main
 			alpha = 1;
 			draw_timer = false;
 
-			time_left = total_time = Preferences.GetIntValue (Preferences.MemQuestionTimeKey) * 10; // Seconds
+			time_left = total_time = Preferences.Get <int> (Preferences.MemQuestionTimeKey) * 10; // Seconds
 
 			StartTimer ();
 		}
@@ -122,6 +122,10 @@ namespace gbrainy.Core.Main
 
 		private void TimerUpdater (object source, ElapsedEventArgs e)
 		{
+			// In slow systems you can get pending events after the timer is disabled
+			if (timer.Enabled == false)
+				return;
+
 			if (shade == false && time_left == 0) {
 				lock (this) {
 					time_left = shading_time;
@@ -176,7 +180,7 @@ namespace gbrainy.Core.Main
 		
 			alpha = 1;
 			gr.Color = new Color (DefaultDrawingColor.R, DefaultDrawingColor.G, DefaultDrawingColor.B, alpha);
-			if (request_answer && DrawAnswer == false) {
+			if (request_answer && Answer.Draw == false) {
 				DrawPossibleAnswers (gr, area_width, area_height, rtl);
 			} else {
 				DrawObjectToMemorize (gr, area_width, area_height, rtl);
@@ -186,7 +190,6 @@ namespace gbrainy.Core.Main
 		public override void DrawPreview (CairoContextEx gr, int width, int height, bool rtl)
 		{
 			gr.Scale (width, height);
-			gr.DrawBackground ();
 			gr.Color = new Cairo.Color (0, 0, 0);
 			gr.LineWidth = LineWidth;
 			DrawObjectToMemorize (gr, width, height, rtl);
@@ -214,7 +217,7 @@ namespace gbrainy.Core.Main
 			double width = 0.04, height = 0.6;
 			const double w = 0.003, h = 0.003;
 
-			gr.DrawTextCentered (x + (width / 2), y + height + 0.05, Catalog.GetString ("Time left"));
+			gr.DrawTextCentered (x + (width / 2), y + height + 0.05, Translations.GetString ("Time left"));
 			gr.Stroke ();
 
 			gr.Save ();
