@@ -18,9 +18,9 @@
  */
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -37,40 +37,41 @@ namespace gbrainy.Games.Logic
 		};
 
 		public override string Name {
-			get {return Catalog.GetString ("Figure pattern");}
+			get {return Translations.GetString ("Figure pattern");}
 		}
 
 		public override string Question {
 			get {return String.Format (
-				Catalog.GetString ("What figure should replace the question mark? Answer {0}, {1} or {2}."),
-				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2));}
+				Translations.GetString ("What figure should replace the question mark? Answer {0}, {1} or {2}."),
+				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2));}
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("The third figure of every row involves somehow combining the first two figures.");}
+			get { return Translations.GetString ("The third figure of every row involves somehow combining the first two figures.");}
 		}
 
 		public override string Rationale {
 			get {
-				return Catalog.GetString ("Superpose the first and second figures and remove the lines that they have in common, then rotate the resulting figure 45 degrees.");
+				return Translations.GetString ("Superpose the first and second figures and remove the lines that they have in common, then rotate the resulting figure 45 degrees.");
 			}
 		}
 
 		protected override void Initialize ()
 		{
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption | GameAnswerCheckAttributes.IgnoreSpaces;
 			random_indices = new ArrayListIndicesRandom ((int) Figures.Last);
 			random_indices.Initialize ();
 
 			for (int i = 0; i < (int) Figures.Last; i++)
 			{
 				if (random_indices[i] == (int) Figures.Cross) {
-					right_answer = GetPossibleAnswer (i);
+					Answer.SetMultiOptionAnswer (i, Answer.GetFigureName (i));
 					break;
 				}
 			}
 		}
 
-		private void DrawRotatedCross (CairoContextEx gr, double x, double y, double size)
+		static private void DrawRotatedCross (CairoContextEx gr, double x, double y, double size)
 		{
 			gr.MoveTo (x, y);
 			gr.LineTo (x + size, y + size);
@@ -101,7 +102,7 @@ namespace gbrainy.Games.Logic
 		{
 			double org_x = DrawAreaX + 0.1;
 			double x = org_x, y = 0.08;
-			const double figure_size = 0.13, space_x = 0.1, space_y = 0.2;
+			const double figure_size = 0.13, space_x = 0.1, space_y = 0.18;
 			double x45, y45, x135, y135, offset;
 
 			base.Draw (gr, area_width, area_height, rtl);
@@ -187,7 +188,7 @@ namespace gbrainy.Games.Logic
 			gr.Stroke ();
 	
 			gr.MoveTo (0.05, y - 0.01 + space_y);
-			gr.ShowPangoText (Catalog.GetString ("Possible answers are:"));
+			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
 
 			// Answers
 			x = org_x;
@@ -208,7 +209,7 @@ namespace gbrainy.Games.Logic
 				}
 			
 				gr.MoveTo (x, y + 0.18);
-				gr.ShowPangoText (GetPossibleFigureAnswer (i));
+				gr.ShowPangoText (Answer.GetFigureName (i));
 
 				x += figure_size + space_x;			
 			}
