@@ -20,7 +20,6 @@
 using System;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -28,10 +27,10 @@ namespace gbrainy.Games.Logic
 	{
 		const double figure_size = 0.3;
 		int after;
-		DateTime position_a, position_b, ans;
+		DateTime position_a, position_b, ans, sample;
 
 		public override string Name {
-			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Time now");}
+			get {return Translations.GetString ("Time now");}
 		}
 
 		public override string Question {
@@ -41,16 +40,23 @@ namespace gbrainy.Games.Logic
 				// http://msdn.microsoft.com/en-us/library/system.globalization.datetimeformatinfo.aspx
 				// For 12-hour clock format use {0:%h} and for 24-hour clock format use {0:%H}. The date formats {0:h} and {0:H} are invalid.
 				//
-				ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0} hours ago it was as long after {1:h tt} as it was before {2:h tt} on the same day. What is the time now? Answer using the hour (e.g.: {3:h tt})"),
-				after, position_a, position_b, position_b));}
+				Translations.GetPluralString (
+					"{0} hour ago it was as long after {1:h tt} as it was before {2:h tt} on the same day. What is the time now? Answer using the hour (e.g.: {3:h tt})",
+					"{0} hours ago it was as long after {1:h tt} as it was before {2:h tt} on the same day. What is the time now? Answer using the hour (e.g.: {3:h tt})",
+					after),
+				after, position_a, position_b, sample));}
 		}
 
 		public override string Rationale {
 			get {
-				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Determine the hour half way between the given times, and then add {0} hours to convert it to the present time."), after);
+				return String.Format (Translations.GetPluralString (
+					"Determine the hour half way between the given times, and then add {0} hour to convert it to the present time.",
+					"Determine the hour half way between the given times, and then add {0} hours to convert it to the present time.",
+					after),
+					after);
 			}
 		}
-		
+
 		protected override void Initialize ()
 		{
 			int hour;
@@ -64,12 +70,18 @@ namespace gbrainy.Games.Logic
 			position_b = new DateTime (now.Year, now.Month, now.Day, hour + 12, 0, 0);
 			ans = new DateTime (now.Year, now.Month, now.Day, ((hour + hour + 12) / 2) + after, 0, 0);
 
+			if (position_b != ans)
+				sample = position_b;
+			else {
+				sample = position_a;
+			}
+
 			// TimeNow Puzzle. Translators: {0} is used to check the hour answered by the user.
 			// Use the right time format specification for your culture
  			// Explanation of the date and time format specifications can be found here:
 			// http://msdn.microsoft.com/en-us/library/system.globalization.datetimeformatinfo.aspx
 			// For 12-hour clock format use {0:%h} and for 24-hour clock format use {0:%H}. The date formats {0:h} and {0:H} are invalid.
-			Answer.Correct = String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0:h tt}"), ans);
+			Answer.Correct = String.Format (Translations.GetString ("{0:h tt}"), ans);
 			Answer.CheckAttributes = GameAnswerCheckAttributes.IgnoreCase | GameAnswerCheckAttributes.IgnoreSpaces;
 		}
 
@@ -79,7 +91,7 @@ namespace gbrainy.Games.Logic
 			gr.DrawClock (DrawAreaX + 0.4, DrawAreaY + 0.4, figure_size,
 				0, 0 /* No hands */);
 
-			gr.DrawTextCentered (0.5, DrawAreaY + 0.3 + figure_size, ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Sample clock"));
+			gr.DrawTextCentered (0.5, DrawAreaY + 0.3 + figure_size, Translations.GetString ("Sample clock"));
 		}
 	}
 }
